#

##

##

##

##

##

##

##

##

    	biotech
    		# neurons

    	summary

    		#
    		#	⚠️ ⚠️ ⚠️ ⚠️
    		#
    		#		Make sure that none of the stages that "biotech"
    		#		utilizes rely on "biotech".
    		#
    		#		For the sake of sanity, please keep the "reliability, testing, etc."
    		#		structure as a "tree, hierarchy, etc." etc. with no coodependencies.
    		#

    	docker
    		docker network create --subnet=192.168.0.0/24 container_network
    		docker run --network container_network --ip 192.168.0.102 -v .:/biotech -it jumps:v2.1.0
    		docker exec -it a6599081a9fb bash

    	install
    		python3 /biotech/moves/install.py

    	source
    		source source.sh

    	git
    		git push --set-upstream git@gitlab.com:status600/climates/biotech.git performance

    	important
    		python3 /biotech/venues/warehouse/0.7.1_various_simultaneous/start.proc.py

    	publishing
    		#
    		#	licenses
    		#
    		python3 -m venv /biotech/venues/warehouse/license_venv
    		source /biotech/venues/warehouse/license_venv/bin/activate

    		#
    		#	statuses
    		#
    		python3 /biotech/venues/stages/biotech/_status/status.proc.py

    		#
    		#	git push
    		#
    		#		if Circle CI is successful, then publish
    		#

    		#
    		#	increase version
    		#

    		#
    		#	poetry auth
    		#
    		rm -rf dist && poetry build --verbose && poetry publish --verbose;

    	important
    		poetry show --tree